/*==============================================================================
   DEMO.C :- DOC/DOCX to PDF Converter Demo Program
   Sub Systems, Inc.
   Software License Agreement  (2009)
   ----------------------------------
   This is a demo program.  The program shows how you can utilize HTML-RTF Converter
   to convert between HTML and RTF formats.
===============================================================================*/
#define  STRICT

#include "windows.h"
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif
#if !defined(WIN32)
  #include "print.h"
  #if defined (__TURBOC__)
    typedef unsigned short USHORT;     // missing in compiler
  #endif
#endif

#include "stdio.h"
#include "stdlib.h"
#include "fcntl.h"
#include "sys\types.h"
#include "sys\stat.h"
#include "io.h"
#include "string.h"

#include "commdlg.h"

/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#undef  huge
#define huge
#undef  FreeProcInstance
#define FreeProcInstance(x)
#define GET_WM_COMMAND_ID(wp,lp) LOWORD(wp)
#define NOTIFY_MSG(wp,lp)        HIWORD(wp)
#define farmalloc  malloc
#define farrealloc realloc
#define farfree    free

#define true       TRUE
#define false      FALSE
#define null       NULL

#include "wps.h"

#include "demo.h"

/****************************************************************************
   Main Windows Routine
****************************************************************************/
int PASCAL WinMain(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int nCmdShow)
{
    MSG msg;
    int i;

    if (DoCmdLine(lpCmdLine)) return 0;        // 20071220: process the command line

    #ifndef WIN32
      int QueueLength=96;
      while (!SetMessageQueue(QueueLength) && (QueueLength-=8));
    #endif

    SetMessageQueue(96);   // needed for OLE2

    lpDemoDlg = MakeProcInstance((FARPROC)DemoDlg, hInst);

    DialogBoxParam(hInstance,"DemoDlg",NULL,(DLGPROC)lpDemoDlg,0);

    FreeProcInstance((FARPROC)lpDemoDlg);       // free the dialog box

    return 0;//(msg.wParam);
}

/****************************************************************************
    DoCmdLine:
    Process the command line.
****************************************************************************/
BOOL DoCmdLine(LPBYTE CmdLine)
{
    BYTE InFile[300],OutFile[300],key[100],nbr[100],company[100];
    int  i,flag,count;
    DWORD id;
    BOOL  result=false;

    if (lstrlen(CmdLine)==0) return FALSE;         // do interactive operation

    //AttachConsole(ATTACH_PARENT_CONSOLE);       // works only on Vs2003 under WindowsXP

    count=sscanf(CmdLine,"%s %s %s %s %s",InFile,OutFile,key,nbr,company);

    if (count!=2 && count>=5) {
       printf("Usage: \n\n");
       printf("   DEMO in-file.rtf out-file.pdf\n\n");
       printf("   or,\n\n");
       printf("   DEMO in-file.rtf out-file.pdf LicenseKey LicenseNbr CompanyName\n\n");
       return TRUE;
    }

    if (count>=5) WpsSetLicenseInfo(key,nbr,company);

    id=WpsNewSession();   // begin a conversion session

    WpsSetBoolProp(id,WPPROP_EXACT_TEXT_PLACEMENT,TRUE);

    if (WpsConvertFile(id,InFile,OutFile)) printf("Done!");
    else printf("Error!");

    WpsEndSession(id);   // end conversion session

    return TRUE;
}

/****************************************************************************
    DemoDlg:
    Display the dialog box.
****************************************************************************/
int FAR PASCAL _export DemoDlg(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
{
    BYTE InFile[300],OutFile[300];
    int  i,flag;
    DWORD id;
    BOOL  result=false;

    switch (message) {
        case WM_INITDIALOG:
            return (FALSE);

        case WM_COMMAND:
            switch (GET_WM_COMMAND_ID(wParam,lParam)) {
                case IDC_PURCHASE:
                   ShellExecute(hDlg,"open","http://www.subsystems.com/wpw.htm",NULL,NULL,0);

                   break;

                case IDOK:
                   SetDlgItemText(hDlg,IDC_STATUS,"");

                   GetDlgItemText(hDlg,IDC_INPUT_FILE,InFile,sizeof(InFile)-1);
                   GetDlgItemText(hDlg,IDC_OUTPUT_FILE,OutFile,sizeof(OutFile)-1);

                   // check the file names
                   if (lstrlen(InFile)==0) {
                      MessageBeep(0);
                      SetFocus(GetDlgItem(hDlg,IDC_INPUT_FILE));
                      return true;
                   }
                   if (lstrlen(OutFile)==0) {
                      MessageBeep(0);
                      SetFocus(GetDlgItem(hDlg,IDC_OUTPUT_FILE));
                      return true;
                   }

                   SetDlgItemText(hDlg,IDC_STATUS,"Converting...");

                   // do the conversion
                   id=WpsNewSession();   // begin a conversion session

                   //WpsSetFlags(id,TRUE,WPFLAG_RETURN_MSG_ID);      // return message id instead of displaying the error on the screen.  The message id can be retrieved after a failed call using the WpsGetLastMessage function
                   //WpsSetFlags(id,TRUE,WPFLAG_SHOW_MISSING_SSZLIB_MSG);      // display message is sszlib dll is missing

                   //WpsSetBoolProp(id,WPPROP_BATCH,TRUE);
                   //WpsSetBoolProp(id,WPPROP_EXPAND_WIDTH,TRUE);  // expand the output pdf width, if necessary, to fit the widest table in the document
                   //WpsSetBoolProp(id,WPPROP_HIDE_TRACKING,TRUE);   // Hide tracking codes
                   //WpsSetBoolProp(id,WPPROP_PDFA,TRUE);
                   WpsSetBoolProp(id,WPPROP_EXACT_TEXT_PLACEMENT,TRUE);
                   //WpsSetBoolProp(id,WPPROP_EMBED_FONTS,TRUE);
                   //WpsSetBoolProp(id,WPPROP_COMPRESS_TEXT,TRUE);
                   //WpsSetBoolProp(id,WPPROP_ENABLE_GDIPLUS,TRUE);        // enable GdiPlus, the ssgp.dll must be installed for this property to be effective
                   //WpsSetPageBorder(id,BRDRTYPE_DBL,20,720,0xFF);
                   //WpsSetNumProp(id,WPPROP_ZOOM_FACTOR,850);  // zoom factor of 950/1000
                   //WpsSetBoolProp(id,WPPROP_OMIT_LAST_EMPTY_PAGE,TRUE);  // omit any last empty page

                   //WpsSetNumProp(id,WPPROP_PERM_FLAGS,PERM_PRINT);
                   //WpsSetTextProp(id,WPPROP_OWNER_PASSWORD,"owner");

                   //WpsSetRepInfo(id,"[","of","]",360,WPREP_BOT|WPREP_CENTER);  // print page number at the bottom of the page

                   if ((BOOL)SendDlgItemMessage(hDlg,IDC_USE_BUFFER,BM_GETCHECK,0,0L)) {  // read the file in the memory buffer and do the conversion
                       HGLOBAL hMem;
                       int InSize,OutSize;
                       LPBYTE pInData;

                       pInData=ReadFromFile(InFile,&InSize);
                       if (pInData!=null && (hMem=WpsConvertBuffer(id,pInData,InSize,&OutSize))) {
                           if (WriteToFile(OutFile,hMem,OutSize)) { // write the memory to the output file
                              result=true;
                              SetFocus(GetDlgItem(hDlg,IDC_INPUT_FILE));   // ask for the next file
                           }
                       }
                       MemFree(pInData);
                   }
                   else {      // convert files directly
                       if (WpsConvertFile(id,InFile,OutFile)) {
                           result=true;
                           SetFocus(GetDlgItem(hDlg,IDC_INPUT_FILE));   // ask for the next file
                       }
                   }

                   WpsEndSession(id);   // end conversion session

                   SetDlgItemText(hDlg,IDC_STATUS,result?"Done!":"Error!");
                   if (result) ShellExecute(hDlg,"open",OutFile,NULL,NULL,SW_SHOW);   // invoke Acrobat to show the test file

                   break;

                case IDCANCEL:
                   EndDialog(hDlg, FALSE);
                   ProcessMsg=FALSE;
                   return (TRUE);
                default:
                   ;
            }
            break;
    }
    return (FALSE);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////// Helper functions
////////////////////////////////////////////////////////////////////////////////////////////////////////////

/******************************************************************************
    ReadFromFile:
    Read the contents of a file into a memory buffer
 ******************************************************************************/
LPBYTE ReadFromFile(LPBYTE InFile, LPINT InSize)
{
    HANDLE hFile=INVALID_HANDLE_VALUE;
    long size=0;
    DWORD BytesRead;
    LPBYTE pMem=NULL;

    hFile=CreateFile(InFile,GENERIC_READ,FILE_SHARE_READ|FILE_SHARE_WRITE,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);
    if (hFile!=INVALID_HANDLE_VALUE) {
       size=SetFilePointer(hFile,0,NULL,FILE_END);
       SetFilePointer(hFile,0,NULL,FILE_BEGIN);
       if (NULL!=(pMem=MemAlloc(size+1))) {
           ReadFile(hFile,pMem,size,&BytesRead,NULL);
           if (size!=(long)BytesRead) return FALSE;
       }
       CloseHandle(hFile);
    }
    else MessageBox(NULL,"Error opening the input file",NULL,MB_OK);

    (*InSize)=(int)size;

    return pMem;
}

/******************************************************************************
    WriteToFile:
    Write the data to the disk file
 ******************************************************************************/
BOOL WriteToFile(LPBYTE OutFile, HGLOBAL hMem, int InSize)
{
    HANDLE hFile;
    OFSTRUCT OpenBuf;
    LPBYTE pMem;
    int BytesWritten;

    unlink(OutFile);
    if (INVALID_HANDLE_VALUE==(hFile=CreateFile(OutFile,GENERIC_WRITE,0,NULL,CREATE_ALWAYS,FILE_ATTRIBUTE_NORMAL,NULL))) {
       MessageBox(NULL,"Error opening the output file",NULL,MB_OK);
       return false;
    }

    pMem=GlobalLock(hMem);

   if (!WriteFile(hFile,pMem,InSize,&((DWORD)BytesWritten),NULL)
           || BytesWritten!=InSize) {
       MessageBox(NULL,"Error writing to the output file",NULL,MB_OK);
       return false;
    }

    GlobalUnlock(hMem);
    GlobalFree(hMem);

    CloseHandle(hFile);             // close file

    return TRUE;
}

/******************************************************************************
    MemAlloc:
    This function simply allocates using the runtime library
*******************************************************************************/
void far *MemAlloc(UINT size)
{
    void far *ptr;

    if (NULL==(ptr=farmalloc(size+1))) MessageBox(NULL,"Error allocating memory",NULL,MB_OK);

    return ptr;
}

/******************************************************************************
    MemReAlloc:
    This function simply reallocates using the runtime library
*******************************************************************************/
void far *MemReAlloc(void far *InPtr,UINT size)
{
    void far *ptr;

    if (NULL==(ptr=farrealloc(InPtr,size+1))) MessageBox(NULL,"Error allocating memory",NULL,MB_OK);

    return ptr;
}

/******************************************************************************
    MemFree:
    This function simply frees a runtime library allocated memory block
*******************************************************************************/
int MemFree(void far *ptr)
{
   if (ptr) farfree(ptr);

   return TRUE;
}

/******************************************************************************
    OurPrintf:
    This routine formats and display a given set of arguments.  The format
    is given by the first argument.  The argument 2 to n contain the
    arguments for the specified format.  The function uses MessageBox to
    display the formatted string.
******************************************************************************/
int OurPrintf(LPSTR fmt,...)
{
    LPSTR ArgStart;
    char string[300];
    HWND hWnd;

    ArgStart=(LPSTR) &fmt;  // pointer to first argument
    ArgStart=&ArgStart[4];  // go past the first argument
    wvsprintf(string,fmt,ArgStart);

    if (NULL!=(hWnd=FindWindow("DBWin",NULL))) { // debug window open
        if (NULL!=(hWnd=GetWindow(hWnd,GW_CHILD))) {    // get the edit window
           int len=lstrlen(string);
           string[len]=0xd;
           string[len+1]=0xa;
           string[len+2]=0;
           #if defined (WIN32)
              SendMessage(hWnd,EM_SETSEL,32767,32767);  // show the last line
              SendMessage(hWnd,EM_REPLACESEL,0,(DWORD)(LPSTR)string);
              SendMessage(hWnd,EM_SCROLLCARET,0,0);     // scroll caret into view
           #else
              SendMessage(hWnd,EM_SETSEL,0,MAKELPARAM(32767,32767));  // show the last line
              SendMessage(hWnd,EM_REPLACESEL,0,(DWORD)(LPSTR)string);
              SendMessage(hWnd,EM_SETSEL,0,MAKELPARAM(32767,32767));  // show the last line
           #endif
        }
    }
    else MessageBox(NULL,string,NULL,MB_OK);
    return TRUE;
}


/****************************************************************************
                      DEMO DIALOG PROCEDURES
****************************************************************************/


