#ifndef WPSH
#define WPSH

/******************************************************************************
               WPS Constants
*******************************************************************************/
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif

// flags
#define WPFLAG_RETURN_MSG_ID  0x1
#define WPFLAG_SHOW_MISSING_SSZLIB_MSG 0x2 // show a message if sszlib not found

#define WPPROP_AUTHOR            0       // author of the document
#define WPPROP_TITLE             1       // title of the document
#define WPPROP_PRODUCER          2       // producer of the document
#define WPPROP_SUBJECT           3       // subject of the document
#define WPPROP_KEYWORDS          4       // keywords of the document
#define WPPROP_CRE_DATE          5       // date of the document
#define WPPROP_MOD_DATE          6       // ModDate of the document
#define WPPROP_COMPRESS_TEXT     7       // True to compress text
#define WPPROP_EMBED_FONTS       8       // True to always embed fonts
#define WPPROP_BOOKMARK          9       // Create bookmarks
#define WPPROP_HYPERLINK        10       // Create hyperlinks
#define WPPROP_MAC_COMPATIBLE   11       // True to create mac compatible pdf file
#define WPPROP_PERM_FLAGS       12       // permission flags PERM_ constants
#define WPPROP_USER_PASSWORD    13       // user password
#define WPPROP_OWNER_PASSWORD   14       // ownwer password
#define WPPROP_EXACT_TEXT_PLACEMENT 15   // place characters at exact positions
#define WPPROP_BATCH            16       // faster processing for smaller files when multiple conversions done in the same session
#define WPPROP_NO_CACHING       17       // disable caaching when writing to disk
#define WPPROP_DO_XPARENT       18       // support transparency
#define WPPROP_NO_PAGE_BM       19       // do not use page bitmap. A page bitmap is needed to support WPPROP_DO_XPARENT flag
#define WPPROP_ZOOM_FACTOR      20       // zoom factor - default 1000
#define WPPROP_ENABLE_GDIPLUS   21       // enable gdiplus - ssgp.dll file must be available for this flag to be effective
#define WPPROP_RC4_128          22       // use RC4 128 bit security when password is specified
#define WPPROP_AES_128          23       // use AES 128 bit security when password is specified
#define WPPROP_EXPAND_WIDTH     24       // expand pdf width to fit the widest table
#define WPPROP_HIDE_TRACKING    25       // TRUE to hide the tracking codes
#define WPPROP_OMIT_LAST_EMPTY_PAGE 26   // do not print the last empty page
#define WPPROP_PDFA_1B          27       // minimum compliance pdf/a-1b
#define WPPROP_PDFA             28       // minimum compliance pdf/a
#define WPPROP_NO_TOC_UPDATE    29       // don't update the table of contents
#define WPPROP_PICT_QUALITY     30       // picture quality, 1=lowest, 5=highest, 3=default
#define WPPROP_USE_ORIG_JPG    31       // use original jpeg data to create pdf
#define WPPROP_TAGGED_PDF       32       // product tagged pdf

#define PERM_PRINT            0x4     // these values are specified by the pdf spec - permission flags
#define PERM_MOD              0x28
#define PERM_COPY             0x10

#define PERM_ALL              (PERM_PRINT|PERM_MOD|PERM_COPY)

#define WPREP_TOP            0x1       // print report information on the top of the page
#define WPREP_BOT            0x2       // print report informatio non the bottom of the page
#define WPREP_CENTER         0x4       // center align the info
#define WPREP_RIGHT          0x8       // right align the info
#define WPREP_NO_PAGE        0x10      // don't print the page number

#define BRDRTYPE_SINGLE           0
#define BRDRTYPE_DBL              1
#define BRDRTYPE_TRIPLE           2
#define BRDRTYPE_SHADOW           3
#define BRDRTYPE_THICK_THIN       4
#define BRDRTYPE_THICK_THIN_THICK 5
#define BRDRTYPE_THIN_THICK       6
#define BRDRTYPE_THIN_THICK_THIN  7
#define BRDRTYPE_NONE             8

// Error messages
#define MSG_FILE_NOT_FOUND     1
#define MSG_NO_EDITOR_INSTANCE 2
#define MSG_READ_ERROR         3
#define MSG_WRITE_ERROR        4
#define MSG_MEMORY_LOCK        5
#define MSG_NO_FILE_SIGNATURE  6
#define MSG_BAD_RTF_FILE       7
#define MSG_BAD_HTML_FILE      8
#define MSG_EXPIRED            9
#define MSG_PDF_INIT_ERROR    10
#define MSG_PDF_OUTPUT        11
#define MSG_TXML_NOT_LOADED   12
#define MSG_DOC_TO_RTF        13
#define MSG_LICENSE_EXCEEDED   15
#define MSG_BAD_LICENSE_NUMBER 16
#define MSG_BAD_LICENSE_KEY    17
#define MSG_INVALID_SERVER_LICENSE 18
#define MSG_LICENSE_EXPIRED    19;

#define MSG_OTHER             99

/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#if defined (WIN32)
   #define WPS_HUGE
   #define _export
#else
   #define WPS_HUGE huge
#endif


/****************************************************************************
   Instructions for packing the following structure
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack(1)
#endif

/****************************************************************************
   Instructions to resume the default structure packing.
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack()
#endif


/******************************************************************************
                     Editor Function Prototype
   When calling WPS from a C program, leave the WPS_CPLUSPLUS symbol undefined.

   When calling WPS from a C++ program, define the WPS_CPLUSPLUS as following:

   #define WPS_CPLUSPLUS extern "C"
   #include "ter.h"
*******************************************************************************/
#ifndef WPS_CPLUSPLUS
   #if defined(__cplusplus)
      #define WPS_CPLUSPLUS extern "C"
   #else
      #define WPS_CPLUSPLUS
   #endif
#endif

WPS_CPLUSPLUS DWORD_PTR   WINAPI _export WpsNewSession();
WPS_CPLUSPLUS BOOL    WINAPI _export WpsEndSession(DWORD_PTR);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsConvertFile(DWORD_PTR,LPBYTE,LPBYTE);
WPS_CPLUSPLUS HGLOBAL WINAPI _export WpsConvertBuffer(DWORD_PTR,LPBYTE,int,LPINT);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsHandleToStr(LPBYTE,int,HANDLE);
WPS_CPLUSPLUS int     WINAPI _export WpsGetLastMessage(DWORD_PTR,LPBYTE,LPBYTE);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsResetLastMessage(DWORD_PTR);
WPS_CPLUSPLUS DWORD   WINAPI _export WpsSetFlags(DWORD_PTR,BOOL,int);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetTextProp(DWORD_PTR,int,LPBYTE);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetBoolProp(DWORD_PTR,int,BOOL);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetNumProp(DWORD_PTR,int,int);
WPS_CPLUSPLUS int     WINAPI _export WpsSetLicenseInfo(LPBYTE, LPBYTE, LPBYTE);

// undocumented functions - please contact Sub Systems before using these functions
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetPaperSize(DWORD_PTR, int, int, int);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetPaperOrient(DWORD_PTR, int);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetPageMargin(DWORD_PTR, int, int, int, int);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetPageBorder(DWORD_PTR, int, int, int, COLORREF);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetRepInfo(DWORD_PTR,LPBYTE,LPBYTE,LPBYTE,int, int);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsHandleToByteArray(LPBYTE,int,HANDLE);
WPS_CPLUSPLUS int     WINAPI _export WpsSetLicenseInfoU(LPWORD,LPWORD,LPWORD);
WPS_CPLUSPLUS BOOL    WINAPI _export WpsSetInServer(BOOL);
WPS_CPLUSPLUS int     WINAPI _export WpsGetLicenseStatus();
WPS_CPLUSPLUS int     WINAPI _export WpsSetLicenseInfo2(LPBYTE, LPBYTE, LPBYTE, LPBYTE);


#endif
